@@ -7,9 +7,9 @@ Enabling
 ~~~~~~~~
 
 The aioredis integration is enabled automatically when using
-:ref:`ddtrace-run <ddtracerun>` or :ref:`patch_all() <patch_all>`.
+:ref:`ddtrace-run <ddtracerun>` or :func:`patch_all() <ddtrace.patch_all>`.
 
-Or use :ref:`patch() <patch>` to manually enable the integration::
+Or use :func:`patch() <ddtrace.patch>` to manually enable the integration::
 
     from ddtrace import patch
     patch(aioredis=True)
@@ -31,7 +31,7 @@ Global Configuration
 Instance Configuration
 ~~~~~~~~~~~~~~~~~~~~~~
 
-To configure the aioredis integration on an per-instance basis use the
+To configure the aioredis integration on a per-instance basis use the
 ``Pin`` API::
 
     import aioredis
